/* SAMHAIN file system integrity testing                                   */
/* Copyright (C) 2000 Rainer Wichmann                                      */
/*                                                                         */
/*  This program is free software; you can redistribute it                 */
/*  and/or modify                                                          */
/*  it under the terms of the GNU General Public License as                */
/*  published by                                                           */
/*  the Free Software Foundation; either version 2 of the License, or      */
/*  (at your option) any later version.                                    */
/*                                                                         */
/*  This program is distributed in the hope that it will be useful,        */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of         */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          */
/*  GNU General Public License for more details.                           */
/*                                                                         */
/*  You should have received a copy of the GNU General Public License      */
/*  along with this program; if not, write to the Free Software            */
/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              */

#include "config_xor.h"

#include "samhain.h"
#include "sh_error.h"

#undef  FIL__
#define FIL__  _("sh_err_console.c")

#include <stdio.h>
#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>
#include <signal.h>

extern int  OnlyStderr;

/* ---- Print out a message. ----
 */
int  sh_log_console (char *errmsg)
{
  static int    fd    = -1;
  static FILE * ofile = NULL;

  int    error;
  struct sigaction sa_new, sa_old;

  SL_ENTER(_("sh_log_console"));

  ASSERT_RET((errmsg != NULL), _("errmsg != NULL"), 0)

  sa_new.sa_handler = SIG_IGN;
  sigemptyset(&sa_new.sa_mask);
  sa_new.sa_flags   = 0;

  /* Ignore SIGPIPE in case the console is actually a pipe.
   */
  retry_sigaction(SIGPIPE, &sa_new, &sa_old);
 
  if (sh.flag.isdaemon == S_FALSE)
    {
      fprintf (stderr, "%s\n", errmsg);
      retry_sigaction(SIGPIPE, &sa_old, NULL);
      SL_RETURN(0, _("sh_log_console"));
    }

  /* --- daemon && initialized ---
   */
  if ( (OnlyStderr == S_FALSE) ) 
    {
      fd    =   open ( sh.srvcons.name, O_WRONLY|O_APPEND|O_NOCTTY);


      if (fd < 0)
	{
	  error = errno;
	  sh_error_handle ((-1), FIL__, __LINE__, error, MSG_SRV_FAIL,
			    _("console"), sh.srvcons.name);
	  retry_sigaction(SIGPIPE, &sa_old, NULL);
	  SL_RETURN(-1, _("sh_log_console"));
	}

      ofile = fdopen (fd, "a");
      if (ofile != NULL)
	{
	  (void) fprintf (ofile, "%s\r\n", errmsg);
	  (void) fclose  (ofile);
	}
      else
	{
	  error = errno;
	  (void) close (fd);
	  sh_error_handle ((-1), FIL__, __LINE__, error, MSG_SRV_FAIL,
			    _("console"), sh.srvcons.name);
	  retry_sigaction(SIGPIPE, &sa_old, NULL);
	  SL_RETURN(-1, _("sh_log_console"));
	}
    } 
  retry_sigaction(SIGPIPE, &sa_old, NULL);
  SL_RETURN(0, _("sh_log_console"));
}
